@@ -30,23 +30,23 @@ def filehash(filename, hashalgo):
     return h.hexdigest()
 
 
-sha1sum = partial(filehash, hashalgo='sha1')
+sha512sum = partial(filehash, hashalgo='sha512')
 s3_bucket_base_url = 'http://mozilla-releng-blobs.s3.amazonaws.com/blobs'
 
 
-def upload_file(hosts, filename, branch, hashalgo='sha1',
+def upload_file(hosts, filename, branch, hashalgo='sha512',
                 blobhash=None, attempts=10):
 
     if blobhash is None:
         blobhash = filehash(filename, hashalgo)
 
-    log.info("Attempting to upload file %s" % filename)
+    log.info("Try to upload %s" % filename)
     host_pool = hosts[:]
     n = 1
     while n <= attempts:
         random.shuffle(host_pool)
         host = host_pool[0]
-        log.info("Picking up %s host after shuffling." % host)
+        log.info("Picked up %s host after shuffling." % host)
         post_params = {
             'host': host,
             'filename': filename,
@@ -54,25 +54,25 @@ def upload_file(hosts, filename, branch, hashalgo='sha1',
             'hashalgo': hashalgo,
             'blobhash': blobhash,
         }
-        log.info("Call _post_file - attempt #%d." % (n))
+        log.info("POST call the file - attempt #%d." % (n))
         if _post_file(**post_params):
             # File posted successfully via blob server.
             # Make sure the resource is available on amazon S3 bucket.
             resource_url = '%s/%s/%s' % (s3_bucket_base_url, hashalgo, blobhash)
             ret = requests.head(resource_url)
             if ret.ok:
-                log.info("File %s uploaded successfully at %s/%s/%s" %
+                log.info("Uploaded %s to %s/%s/%s" %
                      (filename, s3_bucket_base_url, hashalgo, blobhash))
             else:
-                log.info("File failed to be fetched from Amazon S3 bucket.")
+                log.warning("Uploading to Amazon S3 failed.")
             break
         else:
-            log.info("Posting file via blob server failed. Trying again ...")
+            log.warning("POST call failed. Trying again ...")
 
         n += 1
 
     if n == attempts+1:
-        log.info("Nr. of attempts exceeded. Uploading %s file failed!" %
+        log.warning("Nr. of attempts exceeded. Uploading %s file failed!" %
                  (filename))
 
 
@@ -98,17 +98,17 @@ def _post_file(host, filename, branch, hashalgo, blobhash):
     return True
 
 
-def upload_dir(hosts, dirname, branch, hashalgo='sha1'):
-    log.info("Opening the directory to read the files ...")
+def upload_dir(hosts, dirname, branch, hashalgo='sha512'):
+    log.info("Open directory for files ...")
     dir_files = [f for f in os.listdir(dirname)
                  if os.path.isfile(os.path.join(dirname, f))]
 
-    log.debug("Iterate through all files in directory:")
+    log.debug("Go through all files in directory")
     for f in dir_files:
         filename = os.path.join(dirname, f)
         upload_file(hosts, filename, branch)
 
-    log.info("Iteration through directory files is now over.")
+    log.info("Iteration through files over.")
 
 
 def main():
@@ -123,8 +123,8 @@ def main():
     else:
         loglevel = logging.INFO
 
-    logging.basicConfig(format="%(asctime)s - %(levelname)s - %(message)s",
-                        level=loglevel)
+    FORMAT = "(blobuploader) - %(levelname)s - %(message)s"
+    logging.basicConfig(format=FORMAT, level=loglevel)
     logging.getLogger('requests').setLevel(logging.WARN)
 
     if args['--dir']:
